@@ -23,8 +23,8 @@
  * Original Copyright (C)  1998-2002 Free Software Foundation, Inc.
  *
  * Authors:
- *      George Lebl  <jirka@5z.com>
- *      Mark McLoughlin <mark@skynet.ie>
+ *      George Lebl  <jirka@5z.com> (Gnome Fish Applet)
+ *      Mark McLoughlin <mark@skynet.ie> (Gnome Fish Applet)
  *      Josh Buhl <jbuhl@users.sourceforge.net>
  */
 
@@ -201,7 +201,7 @@ display_about_dialog (BonoboUIComponent *uic,
 	char        *file;
 
 	const char *about = _("GNOME Lunar Clock displays the current phase of the moon "
-			      "and pertinant astronomical data.");
+			      "and pertinent astronomical data.");
 
 	if (moon->about_dialog) {
 		gtk_window_set_screen (GTK_WINDOW (moon->about_dialog),
@@ -231,7 +231,7 @@ display_about_dialog (BonoboUIComponent *uic,
 	moon->about_dialog =
 		gnome_about_new (_("GNOME Lunar Clock"),
 				 VERSION,
-				 "Copyright \xc2\xa9 1999-2004 Josh Buhl, et al.",
+				 "Copyright \xc2\xa9 1999-2005 Josh Buhl, et al.",
 				 (const char *) about,
 				 (const char **) authors,
 				 NULL,
@@ -912,7 +912,7 @@ load_moon_image (MoonApplet *moon)
 /* 		if(rgb){ */
 /* 			frame_rgb = gdk_pixbuf_get_pixels(frame_pb); */
 
-/* 			/\* Hilight moon image.  */
+/* 			/\* Hilight moon image for mouseover.  */
 /* 			 * Alpha transparency should not be changed. *\/ */
 /* 			for(i=0; i<rowstride*height; i++){ */
 /* 				rgb[i] = (!has_alpha || i % 4 != 3) ? */
@@ -970,6 +970,8 @@ compose_image (MoonApplet *moon)
 	gdouble    scale = 1.0;
 	guchar    *rgb;
 
+	int i;
+
 	if (!GTK_WIDGET_REALIZED (widget) ||
 	    widget->allocation.width <= 0 ||
 	    widget->allocation.height <= 0)
@@ -999,6 +1001,7 @@ compose_image (MoonApplet *moon)
 				widget->requisition.height = height;
 			}
 		}
+
 	} else {
 		if (rotate) {
 			width  = widget->allocation.width;
@@ -1027,39 +1030,15 @@ compose_image (MoonApplet *moon)
 
 	g_assert (pixbuf_width != -1 && pixbuf_height != -1);
 
-
-/* 	rgb = g_new0 (guchar, width * height * 3); */
-
-/* 	/\* panel_applet_get_bg_rgb(moon, rgb);*\/ */
-	
-/* 	bg_pb = gdk_pixbuf_new_from_data(rgb, GDK_COLORSPACE_RGB, */
-/* 					 FALSE, 8, width, height, rowstride, */
-/* 					 free_pixbuf, NULL); */
-/* 	g_assert(bg_pb); */
-	
 	composite_pb = gdk_pixbuf_new(GDK_COLORSPACE_RGB, TRUE, 8,
 				      width, height);
 	if (!composite_pb)
 		g_error("cannot allocate composing pixbuf.");
-
-	/* sometimes get_rgb returns one pixel less wide than width
-	   in spite of setup_size */
-/* 	gdk_pixbuf_scale(bg_pb, composite_pb, 0, 0, width, */
-/* 			 height, 0, 0, 1, 1, GDK_INTERP_HYPER); */
-	
-/* 	gdk_pixbuf_composite(moon->image_pb, composite_pb, */
-/* 			     0, 0, width, height, */
-/* 			     0, 0, scale, scale, */
-/* 			     GDK_INTERP_HYPER, 255); */
-	
-/* 	gdk_pixbuf_unref(bg_pb); */
-/* 	bg_pb = NULL; */
-
 	
 	gdk_pixbuf_composite_color(moon->image_pb, composite_pb,
 			     0, 0, width, height,
 			     0, 0, scale, scale,
-			     GDK_INTERP_HYPER, 255, 0,0,10,0,0);
+			     GDK_INTERP_HYPER, 255, 0,10,10,0,0);
 
 
 	gdk_pixbuf_render_to_drawable_alpha(composite_pb,
